Module filter

Module filter 

Type Aliases

FilterPredicate
Predicate that determines whether an exchange passes the filter. Returns true to forward the exchange into the filter body; false to skip it.