BoxProcessor

Type Alias BoxProcessor 

pub type BoxProcessor = BoxCloneService<Exchange, Exchange, CamelError>;
A type-erased, cloneable processor. This is the main runtime representation of a processor pipeline — a composed chain of Tower Services erased to a single boxed type.

Aliased Type

pub struct BoxProcessor(/* private fields */);