Module resequencer

Module resequencer 

Resequencer EIP contract types.

Batch/stream policy configs (Tasks 2/3).

Structs

ResequencePolicyConfig
Configuration for the Resequencer EIP.

Enums

BatchCompletion
Window-based completion trigger for batch resequencing.
CapacityPolicy
What to do when the stream resequencer priority queue reaches capacity.
GapPolicy
What to do when a stream resequencer gap timer fires.
ResequenceMode
Configurable resequencing policy mode.