#[non_exhaustive]pub enum GapPolicy {
EmitPartial,
DropAndLog,
}Expand description
What to do when a stream resequencer gap timer fires.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmitPartial
Emit the contiguous run from next_expected and advance past the gap.
DropAndLog
Drop all held exchanges with a warning log (no dead-letter sink wired).