pub struct CanonicalAggregateSpec {
pub header: String,
pub completion_size: Option<usize>,
pub completion_timeout_ms: Option<u64>,
pub correlation_key: Option<String>,
pub force_completion_on_stop: Option<bool>,
pub discard_on_timeout: Option<bool>,
pub strategy: CanonicalAggregateStrategySpec,
pub max_buckets: Option<usize>,
pub bucket_ttl_ms: Option<u64>,
}Fields
header: Stringcompletion_size: Option<usize>completion_timeout_ms: Option<u64>correlation_key: Option<String>force_completion_on_stop: Option<bool>discard_on_timeout: Option<bool>strategy: CanonicalAggregateStrategySpecmax_buckets: Option<usize>bucket_ttl_ms: Option<u64>Trait Implementations
Sourceimpl Clone for CanonicalAggregateSpec
impl Clone for CanonicalAggregateSpec
Sourcefn clone(&self) -> CanonicalAggregateSpec
fn clone(&self) -> CanonicalAggregateSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CanonicalAggregateSpec
impl Debug for CanonicalAggregateSpec
Sourceimpl<'de> Deserialize<'de> for CanonicalAggregateSpec
impl<'de> Deserialize<'de> for CanonicalAggregateSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CanonicalAggregateSpec
impl JsonSchema for CanonicalAggregateSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CanonicalAggregateSpec
impl PartialEq for CanonicalAggregateSpec
Sourcefn eq(&self, other: &CanonicalAggregateSpec) -> bool
fn eq(&self, other: &CanonicalAggregateSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CanonicalAggregateSpec
impl Serialize for CanonicalAggregateSpec
Sourceimpl TS for CanonicalAggregateSpec
impl TS for CanonicalAggregateSpec
Sourcetype WithoutGenerics = CanonicalAggregateSpec
type WithoutGenerics = CanonicalAggregateSpec
If this type does not have generic parameters, then
The only requirement for these dummy types is that
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or (). The only requirement for these dummy types is that
EXPORT_TO must be None. Read moreSourcetype OptionInnerType = CanonicalAggregateSpec
type OptionInnerType = CanonicalAggregateSpec
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete(cfg: &Config) -> String
fn decl_concrete(cfg: &Config) -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl(cfg: &Config) -> String
fn decl(cfg: &Config) -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline(cfg: &Config) -> String
fn inline(cfg: &Config) -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened(cfg: &Config) -> String
fn inline_flattened(cfg: &Config) -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
T should be exported, relative to the output directory.
The returned path does not include any base directory. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies(cfg: &Config) -> Vec<Dependency>where
Self: 'static,
fn dependencies(cfg: &Config) -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
fn export(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
fn export_all(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string(cfg: &Config) -> Result<String, ExportError>where
Self: 'static,
fn export_to_string(cfg: &Config) -> Result<String, ExportError>where
Self: 'static,
impl Eq for CanonicalAggregateSpec
impl StructuralPartialEq for CanonicalAggregateSpec