pub enum StepShutdownReason {
RouteStop,
HotSwap,
}Expand description
Why a stateful pipeline step is being shut down.
Variants
RouteStop
The route is stopping (stop_route).
HotSwap
The pipeline is being replaced via hot reload (Restart path).