Module exchange

Module exchange 

Structs

Exchange
An Exchange represents a message being routed through the framework.

Enums

ExchangePattern
The exchange pattern (fire-and-forget or request-reply).

Constants

PROPERTY_EXCEPTION_CAUGHT
Property key for the caught exception (Java Camel parity alias).
PROPERTY_EXCEPTION_HANDLED
Property key set when an exception has been handled (Java Camel parity).
PROPERTY_EXCEPTION_KIND
Property key for the exception kind (error variant name via classify()).
PROPERTY_EXCEPTION_MESSAGE
Property key for the exception message (error Display string).