Structs
- Exchange
- An Exchange represents a message being routed through the framework.
Enums
- Exchange
Pattern - The exchange pattern (fire-and-forget or request-reply).
Constants
- PROPERTY_
EXCEPTION_ CAUGHT - Property key for the caught exception (Java Camel parity alias).
- PROPERTY_
EXCEPTION_ HANDLED - Property key set when an exception has been handled (Java Camel parity).
- PROPERTY_
EXCEPTION_ KIND - Property key for the exception kind (error variant name via classify()).
- PROPERTY_
EXCEPTION_ MESSAGE - Property key for the exception message (error Display string).