pub type BoxProcessor = BoxCloneService<Exchange, Exchange, CamelError>;Expand description
A type-erased, cloneable processor. This is the main runtime representation of a processor pipeline — a composed chain of Tower Services erased to a single boxed type.
Aliased Type
pub struct BoxProcessor(/* private fields */);Trait Implementations
Sourceimpl BoxProcessorExt for BoxProcessor
impl BoxProcessorExt for BoxProcessor
Sourcefn from_fn<F, Fut>(f: F) -> BoxProcessor
fn from_fn<F, Fut>(f: F) -> BoxProcessor
Create a
BoxProcessor from an async closure. Read more