Resequencer EIP contract types.
Batch/stream policy configs (Tasks 2/3).
Structs
- Resequence
Policy Config - Configuration for the Resequencer EIP.
Enums
- Batch
Completion - Window-based completion trigger for batch resequencing.
- Capacity
Policy - What to do when the stream resequencer priority queue reaches capacity.
- GapPolicy
- What to do when a stream resequencer gap timer fires.
- Resequence
Mode - Configurable resequencing policy mode.